@@ -1,13 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "notmuch-transient" "1.1.3"
+(define-package "notmuch-transient" "20251101.2054"
   "Command dispatchers for Notmuch."
   '((emacs     "29.1")
     (compat    "30.1")
-    (notmuch   "0.39")
-    (transient "0.12"))
+    (notmuch   "0.38")
+    (transient "0.10"))
   :url "https://github.com/tarsius/notmuch-transient"
-  :commit "a1e18fa9202248c3c6264147bd0e82cda0a03a53"
-  :revdesc "v1.1.3-0-ga1e18fa92022"
+  :commit "09861654f1a25a46849f5653a4e9651d9a093ecd"
+  :revdesc "09861654f1a2"
   :keywords '("mail")
   :authors '(("Jonas Bernoulli" . "emacs.notmuch-transient@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.notmuch-transient@jonas.bernoulli.dev")))
